@@ -1,7 +1,30 @@
 require "spec_helper"
 require "rspec/rails/feature_check"
+
 if RSpec::Rails::FeatureCheck.has_active_job?
   require "rspec/rails/matchers/active_job"
+
+  class GlobalIdModel
+    include GlobalID::Identification
+
+    attr_reader :id
+
+    def self.find(id)
+      new(id)
+    end
+
+    def initialize(id)
+      @id = id
+    end
+
+    def ==(comparison_object)
+      id == comparison_object.id
+    end
+
+    def to_global_id(options = {})
+      @global_id ||= GlobalID.create(self, :app => "rspec-suite")
+    end
+  end
 end
 
 RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_active_job? do
@@ -26,30 +49,6 @@ RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_ac
     end
   end
 
-  let(:global_id_model) do
-    Class.new do
-      include GlobalID::Identification
-
-      attr_reader :id
-
-      def self.find(id)
-        new(id)
-      end
-
-      def self.name
-        "AnonymousClass"
-      end
-
-      def initialize(id)
-        @id = id
-      end
-
-      def to_global_id(options = {})
-        @global_id ||= GlobalID.create(self, :app => "rspec-suite")
-      end
-    end
-  end
-
   before do
     ActiveJob::Base.queue_adapter = :test
   end
@@ -61,12 +60,18 @@ RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_ac
       }.to raise_error(ArgumentError)
     end
 
-    it "passess with default one number" do
+    it "passes with default jobs count (exactly one)" do
       expect {
         heavy_lifting_job.perform_later
       }.to have_enqueued_job
     end
 
+    it "passes when using alias" do
+      expect {
+        heavy_lifting_job.perform_later
+      }.to enqueue_job
+    end
+
     it "counts only jobs enqueued in block" do
       heavy_lifting_job.perform_later
       expect {
@@ -74,7 +79,7 @@ RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_ac
       }.to have_enqueued_job.exactly(1)
     end
 
-    it "passess when negated" do
+    it "passes when negated" do
       expect { }.not_to have_enqueued_job
     end
 
@@ -121,20 +126,20 @@ RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_ac
       }.to have_enqueued_job(hello_job).and have_enqueued_job(logging_job)
     end
 
-    it "passess with :once count" do
+    it "passes with :once count" do
       expect {
         hello_job.perform_later
       }.to have_enqueued_job.exactly(:once)
     end
 
-    it "passess with :twice count" do
+    it "passes with :twice count" do
       expect {
         hello_job.perform_later
         hello_job.perform_later
       }.to have_enqueued_job.exactly(:twice)
     end
 
-    it "passess with :thrice count" do
+    it "passes with :thrice count" do
       expect {
         hello_job.perform_later
         hello_job.perform_later
@@ -142,14 +147,14 @@ RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_ac
       }.to have_enqueued_job.exactly(:thrice)
     end
 
-    it "passess with at_least count when enqueued jobs are over limit" do
+    it "passes with at_least count when enqueued jobs are over limit" do
       expect {
         hello_job.perform_later
         hello_job.perform_later
       }.to have_enqueued_job.at_least(:once)
     end
 
-    it "passess with at_most count when enqueued jobs are under limit" do
+    it "passes with at_most count when enqueued jobs are under limit" do
       expect {
         hello_job.perform_later
       }.to have_enqueued_job.at_most(:once)
@@ -190,7 +195,7 @@ RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_ac
     end
 
     it "passes with provided arguments containing global id object" do
-      global_id_object = global_id_model.new(42)
+      global_id_object = GlobalIdModel.new("42")
 
       expect {
         hello_job.perform_later(global_id_object)
@@ -207,5 +212,85 @@ RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_ac
         }.to have_enqueued_job(hello_job).with(42).on_queue("low").at(date).exactly(2).times
       }.to raise_error(message)
     end
+
+    it "throws descriptive error when no test adapter set" do
+      queue_adapter = ActiveJob::Base.queue_adapter
+      ActiveJob::Base.queue_adapter = :inline
+
+      expect {
+        expect { heavy_lifting_job.perform_later }.to have_enqueued_job
+      }.to raise_error("To use ActiveJob matchers set `ActiveJob::Base.queue_adapter = :test`")
+
+      ActiveJob::Base.queue_adapter = queue_adapter
+    end
+
+    it "fails with with block with incorrect data" do
+      expect {
+        expect {
+          hello_job.perform_later("asdf")
+        }.to have_enqueued_job(hello_job).with { |arg|
+          expect(arg).to eq("zxcv")
+        }
+      }.to raise_error { |e|
+        expect(e.message).to match(/expected: "zxcv"/)
+        expect(e.message).to match(/got: "asdf"/)
+      }
+    end
+
+    it "passes multiple arguments to with block" do
+      expect {
+        hello_job.perform_later("asdf", "zxcv")
+      }.to have_enqueued_job(hello_job).with { |first_arg, second_arg|
+        expect(first_arg).to eq("asdf")
+        expect(second_arg).to eq("zxcv")
+      }
+    end
+
+    it "passess deserialized arguments to with block" do
+      global_id_object = GlobalIdModel.new("42")
+
+      expect {
+        hello_job.perform_later(global_id_object, :symbolized_key => "asdf")
+      }.to have_enqueued_job(hello_job).with { |first_arg, second_arg|
+        expect(first_arg).to eq(global_id_object)
+        expect(second_arg).to eq({:symbolized_key => "asdf"})
+      }
+    end
+
+    it "only calls with block if other conditions are met" do
+      noon = Date.tomorrow.noon
+      midnight = Date.tomorrow.midnight
+      expect {
+        hello_job.set(:wait_until => noon).perform_later("asdf")
+        hello_job.set(:wait_until => midnight).perform_later("zxcv")
+      }.to have_enqueued_job(hello_job).at(noon).with { |arg|
+        expect(arg).to eq("asdf")
+      }
+    end
+  end
+
+  describe "have_been_enqueued" do
+    before { ActiveJob::Base.queue_adapter.enqueued_jobs.clear }
+
+    it "passes with default jobs count (exactly one)" do
+      heavy_lifting_job.perform_later
+      expect(heavy_lifting_job).to have_been_enqueued
+    end
+
+    it "counts all enqueued jobs" do
+      heavy_lifting_job.perform_later
+      heavy_lifting_job.perform_later
+      expect(heavy_lifting_job).to have_been_enqueued.exactly(2)
+    end
+
+    it "passes when negated" do
+      expect(heavy_lifting_job).not_to have_been_enqueued
+    end
+
+    it "fails when job is not enqueued" do
+      expect {
+        expect(heavy_lifting_job).to have_been_enqueued
+      }.to raise_error(/expected to enqueue exactly 1 jobs, but enqueued 0/)
+    end
   end
 end
